#ifndef K3BDEVICE_I18N_H
#define K3BDEVICE_I18N_H

#define TRANSLATION_DOMAIN "libk3bdevice"
#include <KLocalizedString>

#endif // K3BDEVICE_I18N_H
